==> jc-1.4.0.tar.gz: soot/jimple/StmtBody.h <==
// public abstract class soot.jimple.StmtBody

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class a93f9b2adf19105a soot_jimple_StmtBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_Body

#include "soot/Body.h"

#ifndef _JC_soot_jimple_StmtBody_H_
#define _JC_soot_jimple_StmtBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_StmtBody$sub_refs	_jc_soot_jimple_StmtBody$sub_refs;
typedef struct _jc_soot_jimple_StmtBody$sub_nonrefs	_jc_soot_jimple_StmtBody$sub_nonrefs;
typedef struct _jc_soot_jimple_StmtBody$refs	_jc_soot_jimple_StmtBody$refs;
typedef struct _jc_soot_jimple_StmtBody$nonrefs	_jc_soot_jimple_StmtBody$nonrefs;
typedef struct _jc_soot_jimple_StmtBody$object	_jc_soot_jimple_StmtBody$object;

typedef const struct _jc_soot_jimple_StmtBody$vmethods	_jc_soot_jimple_StmtBody$vmethods;
typedef const struct _jc_soot_jimple_StmtBody$vtable	_jc_soot_jimple_StmtBody$vtable;
typedef const struct _jc_soot_jimple_StmtBody$vtype	_jc_soot_jimple_StmtBody$vtype;

// Constructors
extern void _jc_soot_jimple_StmtBody$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_StmtBody$object *);
extern void _jc_soot_jimple_StmtBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_StmtBody$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods structure
struct _jc_soot_jimple_StmtBody$vmethods {
};

// Vtable
struct _jc_soot_jimple_StmtBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_jimple_StmtBody$vmethods	soot_jimple_StmtBody;
};

// Vtype
struct _jc_soot_jimple_StmtBody$vtype {
	_jc_type			type;
	_jc_soot_jimple_StmtBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_StmtBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_StmtBody$refs {
    _jc_soot_jimple_StmtBody$sub_refs	soot_jimple_StmtBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_StmtBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_StmtBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_jimple_StmtBody$sub_nonrefs	soot_jimple_StmtBody;
};

// Object instance structure
struct _jc_soot_jimple_StmtBody$object {
	_jc_soot_jimple_StmtBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_StmtBody$vtype	*vtype;
	_jc_soot_jimple_StmtBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_StmtBody$vtype _jc_soot_jimple_StmtBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_StmtBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_StmtBody$class_object;

#endif	/* _JC_soot_jimple_StmtBody_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/StmtBody.h <==
// public abstract class soot.jimple.StmtBody

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6131d54b9700ca5d soot_Body
// @dep_class a93f9b2adf19105a soot_jimple_StmtBody
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_Body

#include "soot/Body.h"

#ifndef _JC_soot_jimple_StmtBody_H_
#define _JC_soot_jimple_StmtBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_StmtBody$sub_refs	_jc_soot_jimple_StmtBody$sub_refs;
typedef struct _jc_soot_jimple_StmtBody$sub_nonrefs	_jc_soot_jimple_StmtBody$sub_nonrefs;
typedef struct _jc_soot_jimple_StmtBody$refs	_jc_soot_jimple_StmtBody$refs;
typedef struct _jc_soot_jimple_StmtBody$nonrefs	_jc_soot_jimple_StmtBody$nonrefs;
typedef struct _jc_soot_jimple_StmtBody$object	_jc_soot_jimple_StmtBody$object;

typedef const struct _jc_soot_jimple_StmtBody$vmethods	_jc_soot_jimple_StmtBody$vmethods;
typedef const struct _jc_soot_jimple_StmtBody$vtable	_jc_soot_jimple_StmtBody$vtable;
typedef const struct _jc_soot_jimple_StmtBody$vtype	_jc_soot_jimple_StmtBody$vtype;

// Constructors
extern void _jc_soot_jimple_StmtBody$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_StmtBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_StmtBody$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_StmtBody$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_StmtBody$vmethods {
};

// Vtable
struct _jc_soot_jimple_StmtBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_Body$vmethods	soot_Body;
	_jc_soot_jimple_StmtBody$vmethods	soot_jimple_StmtBody;
};

// Vtype
struct _jc_soot_jimple_StmtBody$vtype {
	_jc_type			type;
	_jc_soot_jimple_StmtBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_StmtBody$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_StmtBody$refs {
    _jc_soot_jimple_StmtBody$sub_refs	soot_jimple_StmtBody;
    _jc_soot_Body$sub_refs	soot_Body;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_StmtBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_StmtBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_Body$sub_nonrefs	soot_Body;
    _jc_soot_jimple_StmtBody$sub_nonrefs	soot_jimple_StmtBody;
};

// Object instance structure
struct _jc_soot_jimple_StmtBody$object {
	_jc_soot_jimple_StmtBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_StmtBody$vtype	*vtype;
	_jc_soot_jimple_StmtBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_StmtBody$vtype _jc_soot_jimple_StmtBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_StmtBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_StmtBody$class_object;

#endif	/* _JC_soot_jimple_StmtBody_H_ */
